==> qtcreator_3.5.1+dfsg.orig.tar.xz: qt-creator-opensource-src-3.5.1+dfsg/src/plugins/texteditor/generichighlighter/dynamicrule.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "dynamicrule.h"
#include "reuse.h"

using namespace TextEditor;
using namespace Internal;

DynamicRule::DynamicRule() : m_active(false)
{}

DynamicRule::~DynamicRule()
{}

void DynamicRule::setActive(const QString &active)
{ m_active = toBool(active); }

bool DynamicRule::isActive() const
{ return m_active; }

void DynamicRule::replaceExpressions(const QStringList &captures)
{
    doReplaceExpressions(captures);
    updateDynamicRules(children(), captures);
}

namespace TextEditor {
namespace Internal {

void updateDynamicRules(const QList<QSharedPointer<Rule> > &rules, const QStringList &captures)
{
    foreach (QSharedPointer<Rule> rule, rules) {
        DynamicRule *dynamicRule = dynamic_cast<DynamicRule *>(rule.data());
        if (dynamicRule && dynamicRule->isActive())
            dynamicRule->replaceExpressions(captures);
    }
}

} // namespace Internal
} // namespace TextEditor

==> qtcreator_4.8.2.orig.tar.xz: qt-creator-opensource-src-4.8.2/src/plugins/texteditor/generichighlighter/dynamicrule.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "dynamicrule.h"
#include "reuse.h"

using namespace TextEditor;
using namespace Internal;

DynamicRule::DynamicRule() : m_active(false)
{}

DynamicRule::~DynamicRule()
{}

void DynamicRule::setActive(const QString &active)
{ m_active = toBool(active); }

bool DynamicRule::isActive() const
{ return m_active; }

void DynamicRule::replaceExpressions(const QStringList &captures)
{
    doReplaceExpressions(captures);
    updateDynamicRules(children(), captures);
}

namespace TextEditor {
namespace Internal {

void updateDynamicRules(const QList<QSharedPointer<Rule> > &rules, const QStringList &captures)
{
    foreach (QSharedPointer<Rule> rule, rules) {
        auto dynamicRule = dynamic_cast<DynamicRule *>(rule.data());
        if (dynamicRule && dynamicRule->isActive())
            dynamicRule->replaceExpressions(captures);
    }
}

} // namespace Internal
} // namespace TextEditor
